@@ -126,7 +126,7 @@ def saveFile(filename, content, encoding='utf-8', mode='w'):
 # 读取Json, filename-保存文件名, encoding-编码
 def readJson(filename, encoding='utf-8'):
 	jsonStr=readFile(filename, encoding)
-	jsonObj=Json.loads(jsonStr)
+	jsonObj=Json.loads("{}" if jsonStr=="" else jsonStr)
 	return jsonObj
 
 # 保存文件, filename-保存文件名, jsonObj-保存json对象, encoding-编码, mode-a添加w重写
